import { createBaseNeedle } from '../../base/support/needles.mjs';
/**
 * Insert content into ApplicationProperties class
 * @example
 * insertContentIntoApplicationProperties.call(generator, application, {
 *   property: 'private final bar = new Bar();',
 *   proppertyGetter: `
 * public getBar() {
 *     return bar;
 * }`,
 *   propertyClass: `
 * public static class Async {
 *     private String foo = "default";
 * }`,
 * })
 * @example
 * generator.editFile(
 *   'ApplicationProperties.java',
 *   insertContentIntoApplicationProperties({
 *     property: 'private final bar = new Bar();',
 *     proppertyGetter: `
 * public getBar() {
 *     return bar;
 * }`,
 *     propertyClass: `
 * public static class Async {
 *     private String foo = "default";
 * }`,
 *   });
 * );
 */
// eslint-disable-next-line import/prefer-default-export
export function insertContentIntoApplicationProperties(application, needles) {
    if (this) {
        return createBaseNeedle.call(this, {
            filePath: `${application.javaPackageSrcDir}config/ApplicationProperties.java`,
            needlesPrefix: 'application-properties',
        }, needles);
    }
    return createBaseNeedle({
        needlesPrefix: 'application-properties',
    }, needles);
}
